/*---------------------------------------------------------------------------*/
/* File:     SY_EDIT.C                                                       */
/* Author:   R. P. Hanson                                                    */
/* Copyright:R. P. Hanson 1996                                               */
/*           Lothar Bittner is now the authorised custodian of the Atari ST  */
/*           version of this program.                                        */
/*---------------------------------------------------------------------------*/
/* Contents: Main routine.                                                   */
/*---------------------------------------------------------------------------*/
/* Functions:"clr_fsel_area"  clears the area occupied by the file selector. */
/*           "main"           main entry point.                              */
/*---------------------------------------------------------------------------*/
/* Globals:  "mf_norm"        array holding cursor form for program.         */
/*---------------------------------------------------------------------------*/


/*----------*/
/* Includes */
/*----------*/
    #include <string.h>
    #include "types.h"
    #include "sy_vdi.h"

/*-----------*/
/* Externals */
/*-----------*/
    extern int chng_flag ;
    extern int mx, my, mbut, kstat, upd_vect ;

/*---------------------------*/
/* Array holding cursor form */
/*---------------------------*/
    int mf_norm[] = { 0, 0, 1, 0, 1,
                      63488, 65280, 65504, 65504, 65504, 32736, 32704, 32736,
                      16368, 16376, 15868, 254,   127,   63,    31,    15,
                      0,     28672, 32256, 32704, 16320, 16256, 16128, 8064,
                      7616,  6368,  112,   56,    28,    14,    6,     0 } ;

/*--------------------------------------------------------------------------*/
/*  FUNCTION:   "clr_fsel_area"                                             */
/*--------------------------------------------------------------------------*/
/*  PURPOSE:    This function clears the area occupied by the file selector.*/
/*--------------------------------------------------------------------------*/
/*  PARAMETERS: None.                                                       */
/*--------------------------------------------------------------------------*/

    clr_fsel_area ()
    {
        m_point_off ;
        erase_block ( 60, 359, 519, 319 ) ;
        m_point_on ;
    }

/*------------------------------------*/
/*  END OF FUNCTION:  "clr_fsel_area" */
/*------------------------------------*/


/*--------------------------------------------------------------------------*/
/*  FUNCTION:   "main"                                                      */
/*--------------------------------------------------------------------------*/
/*  PURPOSE:    This function is the program entry and the main loop.       */
/*--------------------------------------------------------------------------*/
/*  PARAMETERS: None.                                                       */
/*--------------------------------------------------------------------------*/

    main ()
    {
        hilite_type load_but_f, save_but_f, get_but_f, quit_but_f,
                    el_a_but_f, el_b_but_f, el_c_but_f, el_d_but_f,
                    vect_but_f, glob_but_f ;
        rect_type *rect_point ;
        char exit_f, up_dis ;

        /* Initialise display */
        init_app () ;
        up_dis = 0 ;
        draw_main_screen () ;
        draw_global () ;
        vsc_form ( handle, mf_norm ) ;
        upd_display ( TRUE ) ;
        chng_flag = FALSE ;

        /* Initialise all buttons */
        init_but_flag ( &load_but_f ) ;
        init_but_flag ( &save_but_f ) ;
        init_but_flag ( &get_but_f ) ;
        init_but_flag ( &quit_but_f ) ;
        init_but_flag ( &el_a_but_f ) ;
        init_but_flag ( &el_b_but_f ) ;
        init_but_flag ( &el_c_but_f ) ;
        init_but_flag ( &el_d_but_f ) ;
        init_but_flag ( &glob_but_f ) ;
        init_but_flag ( &vect_but_f ) ;
        exit_f = FALSE ;

        /* Display copyright message */
        text_out ( 400, 240, "SY_EDIT.PRG Version 1.1" ) ;
        text_out ( 400, 252, "(C) 1996 Richard Hanson" ) ;
        text_out ( 400, 262, "This program is shareware." ) ;
        text_out ( 400, 270, "You may freely copy this" ) ;
        text_out ( 400, 278, "program and give it to" ) ;
        text_out ( 400, 286, "your friends (or enemies" ) ;
        text_out ( 400, 294, "if you don't like it!)." ) ;
        text_out ( 400, 306, "If you use this program," ) ;
        text_out ( 400, 314, "please send ten pounds" ) ;
        text_out ( 400, 322, "sterling to me at 28 Albany" ) ;
        text_out ( 400, 330, "Road, Chatham, Kent," ) ;
        text_out ( 400, 338, "ENGLAND, ME4 5DL and I might" ) ;
        text_out ( 400, 346, "even send you a manual for" ) ;
        text_out ( 400, 354, "it, and an upgrade if I ever" ) ;
        text_out ( 400, 362, "do another change!" ) ;

        vq_mouse ( handle, &mbut, &mx, &my ) ;
        do
        {
            /* Check which buttons are pressed */
            check_but_stat ( load_butt, &load_but_f ) ;
            check_but_stat ( save_butt, &save_but_f ) ;
            check_but_stat ( get_butt,  &get_but_f ) ;
            check_but_stat ( quit_butt, &quit_but_f ) ;
            check_but_stat ( el_a_butt, &el_a_but_f ) ;
            check_but_stat ( el_b_butt, &el_b_but_f ) ;
            check_but_stat ( el_c_butt, &el_c_but_f ) ;
            check_but_stat ( el_d_butt, &el_d_but_f ) ;
            check_but_stat ( glob_butt, &glob_but_f ) ;
            check_but_stat ( vect_butt, &vect_but_f ) ;

            /* Get mouse position */
            evnt_timer ( 25, 0 ) ;
            vq_mouse ( handle, &mbut, &mx, &my ) ;
            evnt_timer ( 50, 0 ) ;

            /* Process button selections. Only process when mouse */
            /* button has been released, hence mbut == 0.         */
            if ( quit_but_f.now && ( mbut == 0 ))
                exit_f = TRUE ;
            else if ( el_a_but_f.now && ( mbut == 0 ))
            {
                draw_awm_element ( 0 ) ;
                upd_display ( TRUE ) ;
            }
            else if ( el_b_but_f.now && ( mbut == 0 ))
            {
                draw_fm_element ( 1 ) ;
                upd_display ( TRUE ) ;
            }
            else if ( el_c_but_f.now && ( mbut == 0 ))
            {
                draw_awm_element ( 2 ) ;
                upd_display ( TRUE ) ;
            }
            else if ( el_d_but_f.now && ( mbut == 0 ))
            {
                draw_fm_element ( 3 ) ;
                upd_display ( TRUE ) ;
            }
            else if ( glob_but_f.now && ( mbut == 0 ))
            {
                draw_global () ;
                upd_display ( TRUE ) ;
            }
            else if ( vect_but_f.now && ( mbut == 0 ))
            {
                draw_vector () ;
                upd_vect = 1 ;
                upd_display ( TRUE ) ;
            }
            else if ( get_but_f.now && ( mbut == 0 ))
            {
                in_voice ( 0 ) ;
                upd_display ( TRUE ) ;
                chng_flag = FALSE ;
                upd_vect = 1 ;
            }
            else if ( load_but_f.now && ( mbut == 0 ))
            {
                in_voice ( 1 ) ;
                clr_fsel_area () ;
                up_dis = 1 ;
                upd_vect = 1 ;
                chng_flag = !FALSE ;
            }
            else if ( save_but_f.now && ( mbut == 0 ))
            {
                save_voice () ;
                clr_fsel_area () ;
                up_dis = 1 ;
            }
            else if ( mbut == 0 )
            {
                /* If flag "up_dis" is 1, then completely redraw screen */
                if ( up_dis == 1 )
                {
                    draw_main_screen () ;
                    switch ( curr_edit )
                    {
                        case 0 :
                        case 2 : draw_awm_element ( curr_edit ) ;  break ;
                        case 1 :
                        case 3 : draw_fm_element ( curr_edit ) ;   break ;
                        case 4 : draw_vector() ; break ;
                        case 5 : draw_global() ; break ;
                    }
                    upd_display ( TRUE ) ;
                    up_dis = 0 ;
                    upd_vect = 1 ;
                }
                else if ( chng_flag )
                {
                    out_voice ( 0 ) ;
                    chng_flag = !chng_flag ;
                }
            }

            /* DO EDIT */
            if ( mbut != 0 )
            {
                edit_all () ;
                if (( curr_edit >= 0 ) && ( curr_edit <= 3 ))
                    edit_element () ;
                if ( curr_edit == 5 )
                    edit_global () ;
                upd_display ( FALSE ) ;
            }
            if (( mbut == 0 ) && ( upd_vect == 1 ) && ( curr_edit == 4 ))
            {
                draw_vgraph () ;
                upd_vect = 0 ;
            }
        } while ( !exit_f ) ;

        /* CLOSE APPLICATION */
        close_app () ;
    }

/*----------------------------*/
/*  END OF FUNCTION:  "main"  */
/*----------------------------*/
